summaryrefslogtreecommitdiff
path: root/src/lib/eina/eina_log.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/eina/eina_log.h')
-rw-r--r--src/lib/eina/eina_log.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/eina/eina_log.h b/src/lib/eina/eina_log.h
index b4254fed4f..7b4e17e9a9 100644
--- a/src/lib/eina/eina_log.h
+++ b/src/lib/eina/eina_log.h
@@ -142,7 +142,7 @@
* custom data can be passed to that callback, powerful display
* messages can be displayed.
*
* It is suggested to not use __FILE__, __FUNCTION__ or __LINE__ when
* writing that callback, but when defining macros (like
* EINA_LOG_ERR() and other macros).
*
@@ -304,7 +304,7 @@ EAPI extern int EINA_LOG_DOMAIN_GLOBAL;
# define EINA_LOG(DOM, LEVEL, fmt, ...) \
do { \
if (LEVEL <= EINA_LOG_LEVEL_MAXIMUM) { \
- eina_log_print(DOM, LEVEL, __FILE__, __FUNCTION__, __LINE__, \
+ eina_log_print(DOM, LEVEL, __FILE__, __func__, __LINE__, \
fmt, ## __VA_ARGS__); } \
} while (0)
# else
@@ -312,7 +312,7 @@ EAPI extern int EINA_LOG_DOMAIN_GLOBAL;
eina_log_print(DOM, \
LEVEL, \
__FILE__, \
- __FUNCTION__, \
+ __func__, \
__LINE__, \
fmt, \
## __VA_ARGS__)
@@ -142,7 +142,7 @@
* messages can be displayed.
*
- * It is suggested to not use __FILE__, __FUNCTION__ or __LINE__ when
+ * It is suggested to not use __FILE__, __func__ or __LINE__ when
* writing that callback, but when defining macros (like
* EINA_LOG_ERR() and other macros).